==> styled-bootstrap-0.1.7-0.tgz: package/lib/Pagination/Pagination.js <==
var _templateObject = _taggedTemplateLiteral(['\n  display: flex;\n  ', ';\n  ', ';\n\n  ', ';\n\n  ', ';\n'], ['\n  display: flex;\n  ', ';\n  ', ';\n\n  ', ';\n\n  ', ';\n']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import styled from 'styled-components';

import get from 'lodash.get';

import { borderRadius } from '../utils/src/border-radius';

import { paginationSize } from './pagination-size';
import listUnstyled from '../utils/src/lists';

import PaginationLink from './PaginationLink';
import PaginationItem from './PaginationItem';

import { paginationPaddingYsm, paginationPaddingXsm, paginationPaddingYlg, paginationPaddingXlg, fontSizeLg, lineHeightLg, borderRadiusLg, fontSizeSm, lineHeightSm, borderRadiusSm } from './default-theme';

var Pagination = styled.ul(_templateObject, listUnstyled, borderRadius(), function (_ref) {
  var size = _ref.size,
      theme = _ref.theme;
  return size === 'large' && paginationSize(get(theme, 'paginationPaddingYlg', paginationPaddingYlg), get(theme, 'paginationPaddingXlg', paginationPaddingXlg), get(theme, 'fontSizeLg', fontSizeLg), get(theme, 'lineHeightLg', lineHeightLg), get(theme, 'borderRadiusLg', borderRadiusLg));
}, function (_ref2) {
  var size = _ref2.size,
      theme = _ref2.theme;
  return size === 'small' && paginationSize(get(theme, 'paginationPaddingYsm', paginationPaddingYsm), get(theme, 'paginationPaddingXsm', paginationPaddingXsm), get(theme, 'fontSizeSm', fontSizeSm), get(theme, 'lineHeightSm', lineHeightSm), get(theme, 'borderRadiusSm', borderRadiusSm));
});

Pagination.Link = PaginationLink;
Pagination.Item = PaginationItem;

Pagination.defaultProps = {};

Pagination.propTypes = {};

export default Pagination;

==> styled-bootstrap-0.1.9.tgz: package/lib/Pagination/Pagination.js <==
var _templateObject = _taggedTemplateLiteral(['\n  display: flex;\n  ', ';\n  ', ';\n\n  ', ';\n\n  ', ';\n'], ['\n  display: flex;\n  ', ';\n  ', ';\n\n  ', ';\n\n  ', ';\n']);

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

import styled from 'styled-components';

// $FlowIssue
import get from 'lodash.get';

import { borderRadius } from '../utils/border-radius';

import { paginationSize } from './pagination-size';
import listUnstyled from '../utils/lists';

import PaginationLink from './PaginationLink';
import PaginationItem from './PaginationItem';

import { paginationPaddingYsm, paginationPaddingXsm, paginationPaddingYlg, paginationPaddingXlg, fontSizeLg, lineHeightLg, borderRadiusLg, fontSizeSm, lineHeightSm, borderRadiusSm } from './default-theme';

var Pagination = styled.ul(_templateObject, listUnstyled, borderRadius(), function (_ref) {
  var size = _ref.size,
      theme = _ref.theme;
  return size === 'large' && paginationSize(get(theme, 'paginationPaddingYlg', paginationPaddingYlg), get(theme, 'paginationPaddingXlg', paginationPaddingXlg), get(theme, 'fontSizeLg', fontSizeLg), get(theme, 'lineHeightLg', lineHeightLg), get(theme, 'borderRadiusLg', borderRadiusLg));
}, function (_ref2) {
  var size = _ref2.size,
      theme = _ref2.theme;
  return size === 'small' && paginationSize(get(theme, 'paginationPaddingYsm', paginationPaddingYsm), get(theme, 'paginationPaddingXsm', paginationPaddingXsm), get(theme, 'fontSizeSm', fontSizeSm), get(theme, 'lineHeightSm', lineHeightSm), get(theme, 'borderRadiusSm', borderRadiusSm));
});

Pagination.Link = PaginationLink;
Pagination.Item = PaginationItem;

Pagination.defaultProps = {};

Pagination.propTypes = {};

export default Pagination;
